Girder worker |build-status|
========================

A flexible, simple script execution engine that integrates with the
`Girder <http://girder.readthedocs.org>` data management system to run
distributed batch jobs.

The worker supports running tasks in many environments including python, R,
Scala, pyspark, Julia, and Docker, and supports fetching and pushing data to
and from various data sources, including Girder.

Visit the `documentation <http://girder_worker.readthedocs.org>`_ for more details and API documentation.

.. |build-status| image:: https://travis-ci.org/girder/girder_worker.png?branch=master
    :target: https://travis-ci.org/girder/girder_worker
    :alt: Build Status
